@@ -1,6 +1,5 @@
 use std::{
     fmt::{self, Debug, Formatter},
-    io::{Error as IoError, ErrorKind},
     str::FromStr,
 };
 
@@ -58,7 +57,7 @@ impl Field {
     }
 
     /// Get the full data of the field as bytes.
-    pub async fn bytes(self) -> Result<Vec<u8>, IoError> {
+    pub async fn bytes(self) -> Result<Vec<u8>, ParseMultipartError> {
         let mut data = Vec::new();
         let mut buf = [0; 2048];
         let mut reader = self.into_async_read();
@@ -76,14 +75,14 @@ impl Field {
 
     /// Get the full field data as text.
     #[inline]
-    pub async fn text(self) -> Result<String, IoError> {
-        String::from_utf8(self.bytes().await?).map_err(|err| IoError::new(ErrorKind::Other, err))
+    pub async fn text(self) -> Result<String, ParseMultipartError> {
+        Ok(String::from_utf8(self.bytes().await?)?)
     }
 
     /// Write the full field data to a temporary file and return it.
     #[cfg(feature = "tempfile")]
     #[cfg_attr(docsrs, doc(cfg(feature = "tempfile")))]
-    pub async fn tempfile(self) -> Result<File, IoError> {
+    pub async fn tempfile(self) -> Result<File, ParseMultipartError> {
         let mut reader = self.into_async_read();
         let mut file = tokio::fs::File::from_std(::libtempfile::tempfile()?);
         tokio::io::copy(&mut reader, &mut file).await?;
@@ -95,7 +94,7 @@ impl Field {
     pub fn into_async_read(self) -> impl AsyncRead + Send {
         tokio_util::io::StreamReader::new(
             self.0
-                .map_err(|err| std::io::Error::new(ErrorKind::Other, err.to_string())),
+                .map_err(|err| std::io::Error::new(std::io::ErrorKind::Other, err.to_string())),
         )
     }
 }
